﻿#! /usr/bin/python3
# -*- coding: UTF-8 -*-

# 22.03.2016

import time
from tkinter import messagebox
from rs232 import RS232

START_BYTE = 0xA5
ERROR_BYTE = 0x5A
WRITE1x = 0xA1
WRITE2x = 0xA2

GATEWAY_ERROR = 5


class DaliGateWay(object):
    def __init__(self, ser=None):
        self.ser = ser
        self.send_twice = False
        self.rx_byte_flag = 0
        self.rx_byte_received = None
        self.received = False

        self.rs232 = RS232(ser=self.ser, callback=self.rs232_callback)
        self.rs232.start()

    def quit(self):
        self.rs232.quit()

    def set_light_by_adr(self, adr, level):
        self.dali_send_cmd((adr << 1, level))

    def set_light_by_grp(self, group, level):
        self.dali_send_cmd((0x80 + (group << 1), level))

    def get_light(self, adr):
        return self.dali_send_cmd(((adr << 1) + 1, 0xA0))

    def set_dtr(self, value):
        self.dali_send_cmd((0xA3, value), send_twice=True)

    def set_dtr_2_scene(self, adr, scene):
        self.dali_send_cmd(((adr << 1) + 1, 64 + scene), send_twice=True)

    def set_light_2_dtr(self, adr):
        self.dali_send_cmd(((adr << 1) + 1, 33), send_twice=True)

    # def set_scene(self, adr, scene):
    #     self.dali_send_cmd(((adr << 1) + 1, 64 + scene), send_twice=True)

    def get_scene(self, adr, scene):
        return self.dali_send_cmd(((adr << 1) + 1, 176 + scene))

    def recall_scene_by_adr(self, adr, scene):
        self.dali_send_cmd(((adr << 1) + 1, 16 + scene))

    def recall_scene_by_grp(self, group, scene):
        self.dali_send_cmd((0x80 + (group << 1) + 1, 16 + scene))

    def dali_send_cmd(self, cmd, send_twice=False):
        """
        Führt ein Command aus und liefert die Rückmeldung zurück
        :param cmd: Kommando als Tuple aus 2 Byte
        :param send_twice: das Kommando 2x senden
        :return: Falls eine Rückgabe erfolgt -> 1 Byte, sonst NOTHING = "nv"
        """
        self.received_byte = None
        self.received = False

        if send_twice:
            self.ser.write(bytes((START_BYTE, cmd[0], cmd[1], WRITE2x)))
        else:
            self.ser.write(bytes((START_BYTE, cmd[0], cmd[1], WRITE1x)))

        # print("write", cmd)

        # warten, bis die Antwort eingegangen ist
        # das dauert - wenn der Slave nicht antwortet: 15.83ms + 9.17ms = 25ms
        #              wenn der Slave antwortet 15.83 + (2.92 - 9.17ms) + 9.17ms
        # bei send_twice = True jeweils die doppelte Zeit
        i = 0
        while self.received is False:
            time.sleep(0.005)
            i += 1
            if i > 20:
                messagebox.showerror("Error", "Keine Antwort vom DALI-Gateway empfangen.\nAnschluss / Power prüfen !")
                # print("DALI-Read:", "No Answer from Gateway !")
                self.rx_byte_flag = GATEWAY_ERROR
                break

        # self.rx_byte_flag zeigt den Erfolg an
        # wenn == 0, dann wurde ein Wert empfangen
        if self.rx_byte_flag == 0:
            return self.rx_byte_received
        else:
            return -1

    def rs232_callback(self, data):
        """
        :param data: die Daten, die von der Seriellen Schnittstelle empfangen wurden, als Liste
        :return:
        rs232_callback für den Empfang der Daten über die serielle Schnittstelle
        Das Flag 'received' signalisiert, dass Daten  empfangen wurden
        """

        # Das Flag zeigt die Rückmeldung des Gateways zu Rückmeldung des DALI-Slaves an
        # 0 = Daten empfangen
        # 1 = keine Rückmeldung
        # >1 = Fehler
        self.rx_byte_flag = data[0]
        # Das Datenbyte steht nun in der Variablen rx_byte_received
        self.rx_byte_received = data[1]
        # Das Flag wird benutzt, um den Eingang der Antwort zu signalisieren
        # Daraufhin beendet dali_write_bytes() seine Warteschleife
        self.received = True
