#!/usr/bin/python
# -*- coding: UTF-8 -*-
#   12.10.2015

import tkinter as tk
from lightdialog import LightDialog
from scenedialog import Scene_Dialog


class Light(object):
    dali = None

    def __init__(self, master, canvas, x, y, room, length=15, level=254, shape="square",
                 is_dimmable=True, name="", group=20, dali_id=63):
        self.master = master
        self.canvas = canvas
        self.dali_id = dali_id
        self.name = name
        self.room = room
        self.group = group
        self.is_dimmable = is_dimmable

        lx = str(x - length // 2)
        ly = str(y - length // 2)
        rx = str(x + length // 2)
        ry = str(y + length // 2)

        # Quadrat
        if shape == "square":
            self.lamp = canvas.create_rectangle(lx, ly, rx, ry, width=2, outline="black")
            canvas.create_text(str(x + length), str(y), text=self.group, font=("Helvetica", "10"), justify=tk.CENTER)

        # horizontale Rechteck
        elif shape == "rectangle_h":
            lx = str(x - length * 2)
            ly = str(y - 5)
            rx = str(x + length * 2)
            ry = str(y + 5)
            xtxt = str(x + 2 * length + 10)
            self.lamp = canvas.create_rectangle(lx, ly, rx, ry, width=2, outline="black")
            canvas.create_text(xtxt, str(y), text=self.group, font=("Helvetica", "10"), justify=tk.CENTER)

        # vertikales Rechteck
        elif shape == "rectangle_v":
            lx = str(x - 4)
            ly = str(y - length * 2)
            rx = str(x + 4)
            ry = str(y + length * 2)
            xtxt = str(x + 12)
            self.lamp = canvas.create_rectangle(lx, ly, rx, ry, width=2, outline="black")
            canvas.create_text(xtxt, str(y), text=self.group, font=("Helvetica", "10"), justify=tk.CENTER)

        # Leuchte als Kreis
        elif shape == "circle":
            self.lamp = canvas.create_arc(lx, ly, rx, ry, style=tk.CHORD, start=0, extent=359,
                                          width=2, outline="black")
            canvas.create_text(str(x + length), str(y), text=self.group, font=("Helvetica", "10"),
                               justify=tk.CENTER)
        elif shape == "diamant":
            px1 = str(x - length // 2)
            py1 = str(y)
            px2 = str(x)
            py2 = str(y - length // 2)
            px3 = str(x + length // 2)
            py3 = str(y)
            px4 = str(x)
            py4 = str(y + length // 2)
            self.lamp = canvas.create_polygon(px1, py1, px2, py2, px3, py3, px4, py4,
                                              width=2, outline="black")
            canvas.create_text(str(x + length), str(y), text=self.group, font=("Helvetica", "10"),
                               justify=tk.CENTER)
        else:
            print("shape-Error in lamp.py: {}".format(shape))
            exit()

        canvas.tag_bind(self.lamp, '<1>', self.press_1)
        canvas.tag_bind(self.lamp, '<Shift-1>', self.press_s1)
        self.set_level(level)

    def set_level(self, level):
        """ Setzt die Helligkeit des Leuchtensymbols auf den gegebenen Wert, sofern die Leucht dimmbar ist
        bei einem Wert < 0 wird die Farbe auf Rot gesetzt
        :param level: 0 ... 254
        """
        if self.is_dimmable:
            if level > 0:
                level = int((level / 2) + 120)
                v_hex = "#{:02X}{:02X}00".format(level, level) * 2

            elif level == 0:
                v_hex = "#707070"

            else:
                v_hex = "#FF0000"
            self.canvas.itemconfigure(self.lamp, fill=v_hex)
        # nicht dimmbare Leuchte
        else:
            if level > 0:
                v_hex = "#FFFF00"
            elif level == 0:
                v_hex = "#707070"
            else:
                v_hex = "#FF0000"
            self.canvas.itemconfigure(self.lamp, fill=v_hex)

    def get_group(self):
        # Gibt die zugeordnete Gruppe der Leucht zurück
        return self.group

    def delete_scene(self, scene):
        """ 255 bedeutet, dass die Scene nicht definiert ist, dieser Wert wird in die Szene geschrieben
        :param scene:
        """
        print("delete scene", scene)
        # 255 nach DTR schreiben
        self.__class__.dali.set_dtr(255)
        # DTR = 255 in die Szene schreiben
        self.__class__.dali.set_dtr_2_scene(self.dali_id, scene)

    def press_1(self, unused):
        """ Eine Leuchte wurde mit der linken Maustaste angeklickt
        :param unused:
        """
        # holt den aktuellen Lightlevel aus der Leuchte holen
        level = int(self.__class__.dali.get_light(self.dali_id))
        # antwortet die adressierte Leuchte nicht, dann wird -1 zurückgegben
        # und der Dialog wird erst garnicht aufgerufen
        if level < 0:
            self.canvas.bell()
            self.set_level(-1)
            return

        # print("Dali adr: ", self.dali_id, "Level:", level)
        dialog = LightDialog(self.master, level, self.is_dimmable, self.room.get_name(), self.name, self.group)
        level, group, scene = dialog.start()

        # print("lamp/press_1: level {} group {}, scene {}".format(level, group, scene))
        # group: -1 einzelne Leuchte, >= 0 -> Gruppe
        # scene_ -1 = keine Scene, >= 0 -> Scene
        # level < 0 = Abbruch, >= 0 -> Lightlevel
        if level >= 0:
            # eine ganze Gruppe ändern
            if group >= 0:
                # Helligkeit einstellen
                if scene < 0:
                    self.room.set_group_level(group, level)
                # Szene auswählen
                else:
                    self.room.recall_group_scenes(group, scene)

            # nur eine einzelne Leuchte ändern
            # das wird hier direkt behandelt ...
            else:
                #  eine Helligkeit einstellen
                if scene < 0:
                    self.set_level(level)
                    # print("lamp set:", level)
                    self.__class__.dali.set_light_by_adr(self.dali_id, level)
                # eine Szene auswählen
                else:
                    # print("Lamp:", self.dali_id, "Scene:", scene)
                    self.__class__.dali.recall_scene_by_adr(self.dali_id, scene)

                    light = int(self.__class__.dali.get_scene(self.dali_id, scene))
                    # ein Fehler liefert -1, und -1 schaltet das Leuchtsymbol auf rot
                    self.set_level(light)

    def press_s1(self, unused):
        """ Shift-Linke-Maustaste auf einer Leuchte gedrückt
        :param unused:
        """
        sc = Scene_Dialog(self.master, self.room.get_name(), self.name, self.group)
        scene, selection, action = sc.start()
        # print("scene {} selection {} action {}".format(scene, selection, action))

        # scene = idx - 1
        # selection: -1 = Lampe, -2 = Raum, 0-15 = Gruppe
        # action: 0 = setzen, -1 = löschen
        # print(scene, selection)
        # wenn keine Scene ausgewählt, dann ist nichts zu tun
        if scene < 0:
            return
        # gesamten Raum ändern
        elif selection == -2:
            if action == 0:
                self.room.set_scenes(scene)
            else:
                self.room.delete_scenes(scene)

        # einzelne Leuchte ändern
        elif selection == -1:
            if action == 0:
                # print("Szene speichern: scene")
                # Helligkeit in DTR speichern
                self.__class__.dali.set_light_2_dtr()
                # DTR in Scene speichern
                self.__class__.dali.set_dtr_2_scene(self.dali_id, scene)
                # self.set_scene(scene)
            else:
                self.delete_scene(scene)

        # Gruppe ändern
        elif 0 <= selection <= 15:
            if action == 0:
                self.room.set_group_scenes(selection, scene)
            else:
                self.room.delete_group_scenes(selection, scene)
