#!/usr/bin/python3
# -*- coding: UTF-8 -*-
#   12.10.2015
#

import tkinter as tk
from tkinter import ttk
from cl_Combo import Combo


# ------------------------------------------------------------------------------
class LightDialog(object):
    """ Ein Dialog zur Einstellung der Helligkeit """
    # rechnet intern mit den Werten 0 .. 100 und zeigt Prozent an
    # in allen anderen Programmteilen wird mit dem Bereich 0 ... 254 gearbeitet

    # speichert die letzte Szenenauswahl und den Status der Radio- und Checkbuttons
    last_scene_selection = 0
    last_scene_state = 0
    last_grp_state = 0

    def __init__(self, master, level, is_dimmable=True, room="", name="", group=""):
        self.abbort = False
        self.master = master
        self.group = group

        self.top = tk.Toplevel()
        self.top.title("{}, {}, Gruppe {}".format(room, name, group))
        self.top.protocol('WM_DELETE_WINDOW', self._quit)
        self.top.bind('<Escape>', self._quit)
        self.top.resizable(width=False, height=False)  # Größe nicht veränderbar

        xy = (self.master.geometry().split('+'))
        x = int(xy[1]) + 200
        y = int(xy[2]) + 150
        xy = "+{}+{}".format(x, y)
        self.top.geometry(xy)

        self.frm = ttk.LabelFrame(self.top, text="Einstellung der Helligkeit")
        self.frm.grid(column=0, row=0, padx=5, pady=5, sticky="nsew")

        self.sc_var = tk.IntVar()
        self.sc_var.set(int(level * 100 / 254))
        if is_dimmable:
            tk.Scale(
                self.frm,  # das Parent-Window
                label="Dimmen (0% - 100%)",  # Beschriftung
                showvalue=1,  # [0/1] den Wert anzeigen
                relief="sunken",
                sliderrelief="raised",
                state="normal",  #
                tickinterval=10,  # Interval der Anzeige
                from_=0,  # Wertebereich von ..
                to=100,  # Wertebereich .. bis
                resolution=1,  # Intervall der Werte
                variable=self.sc_var,  # die steuernde Variabel
                width=10,  # die Höhe des Scale
                length=300,  # die Länge des Scale
                orient="horizontal"  # die Ausrichtung des Scale
            ).grid(column=0, columnspan=3, row=0, padx=5, pady=5, sticky="nsew")

        else:
            tk.Scale(
                self.frm,  # das Parent-Window
                label="Nicht dimmbar",  # Beschriftung
                showvalue=1,  # [0/1] den Wert anzeigen
                relief="flat",
                sliderrelief="flat",
                state="normal",  #
                tickinterval=100,  # Interval der Anzeige
                from_=0,  # Wertebereich von ..
                to=100,  # Wertebereich .. bis
                resolution=100,  # Intervall der Werte
                variable=self.sc_var,  # die steuernde Variabel
                width=10,  # die Höhe des Scale
                length=300,  # die Länge des Scale
                orient="horizontal"  # die Ausrichtung des Scale
            ).grid(column=0, columnspan=3, row=0, padx=5, pady=5, sticky="nsew")

        # self.combo = ttk.Combobox(self.frm, values=self.portlist,
        #         state="readonly", height=2, width = 6)
        # self.combo.set(self.portlist[0])
        # self.combo.grid(column = 0, row = 1,padx = 5, pady = 5, sticky = "nswe")
        # self.combo.bind("<<ComboboxSelected>>", self._change_selection)
        #
        # self.lbl = ttk.Label(self.frm, text = "COM-Port auswählen:")
        # self.lbl.grid(column = 0, row = 0, columnspan = 2, padx = 5, pady = 5, sticky = "NSEW")
        buttons = (("Licht AUS [   0 % ]", 0, 1, self.set_off),
                   ("Licht EIN [ 100 % ]", 2, 1, self.set_on),
                   ("Übernehmen", 2, 3, self.übernehmen),
                   ("Abbrechen", 2, 4, self._quit))

        for b in buttons:
            ttk.Button(self.frm, text=b[0], width=18, command=b[3]).grid(
                column=b[1], row=b[2], padx=5, pady=5, sticky="nsew")

        self.chkgrp = tk.IntVar()
        self.chkgrp.set(self.__class__.last_grp_state)
        ttk.Checkbutton(self.frm, text="gesamte Gruppe: {}".format(self.group), variable=self.chkgrp, width=18).grid(
            column=0, row=2, padx=5, pady=5, sticky="nsw")

        self.chkscene = tk.IntVar()
        self.chkscene.set(self.__class__.last_scene_state)
        ttk.Checkbutton(self.frm, text="Szene übernehmen", variable=self.chkscene, width=18).grid(
            column=0, row=3, padx=5, pady=5, sticky="nsw")
        self.combo = Combo(self.frm, row=4)
        self.combo.set_idx(self.__class__.last_scene_selection)

    def start(self):
        self.top.focus_set()  # den Focus auf das Fenster setzen
        self.top.transient(self.master)  # das Fenster im Vordergrund vor "root" halten
        self.top.grab_set()  # events gehen nur an diesen Dialog
        self.top.wait_window(self.top)  # warten bis das Fenster geschlossen wird

        # ein destroy() beendet das Fenster, nun entscheidet abbort ....
        if self.abbort:
            return -1, -1, -1
        else:
            if self.chkgrp.get() == 0:
                self.group = -1
            if self.chkscene.get() == 0:
                scene = -1
            else:
                scene = self.combo.get_idx()
            return int(int(self.sc_var.get()) * 254 / 100), self.group, scene

    def set_off(self):
        self.chkscene.set(0)
        self.sc_var.set(0)

    def set_on(self):
        self.chkscene.set(0)
        self.sc_var.set(100)

    def übernehmen(self):
        # die letzte Einstellung der Szene speichern
        self.__class__.last_scene_selection = self.combo.get_idx()
        self.__class__.last_scene_state = self.chkscene.get()
        self.__class__.last_grp_state = self.chkgrp.get()
        self.top.destroy()

    def _quit(self):
        # Ein Abbruch wird mit abbort = True signalisiert
        self.abbort = True
        self.top.destroy()


if __name__ == '__main__':
    top = tk.Tk()
    s = LightDialog(top, 55, True)
    print("Ausgewählt wurde:", s.start())
