# -*- coding: UTF-8 -*-

from xml.sax import make_parser, handler


def xml_read(file):
    parser = make_parser()
    b = MyObjektHandler()
    parser.setContentHandler(b)
    parser.parse(file)
    return b.floorplanfile, b.floorplansize, b.floorwindowsize, b.projektname, b.roomlist, b.lightlist, b.switchlist


class MyObjektHandler(handler.ContentHandler):
    floorplanfile = "??"
    floorplansize = (0, 0)
    floorwindowsize = (0, 0)
    projektname = "??"

    def __init__(self):
        handler.ContentHandler.__init__(self)
        self.area = []
        self.name = ""
        self.room_id = ""
        self.light_group_id = 255
        self.dali_id = ""
        self.group = ""
        self.xy = [0, 0]
        self.offset = (0, 0)
        self.dimmable = 0
        self.shape = ""
        self.length = 20
        self.room_origin = []
        self.scale = 1
        self.current_content = ""
        self.roomlist = []
        self.lightlist = []
        self.switchlist = []

    def startElement(self, name, attrs):
        if name in ("room", "light", "switch"):
            self.current_content = ""
            self.name = ""
            self.room_id = ""
            self.light_group_id = 255
            self.area = []
            self.xy = 0               

    def characters(self, content):
        content = content.strip()
        if len(content):
            self.current_content += content

    def endElement(self, name):
        if name == "xy":
            xy = self.current_content.split(',')
            self.xy = int(int(xy[0]) * self.scale), int(int(xy[1]) * self.scale)
           
        elif name == "name":
            self.name = self.current_content

        elif name == "area":
            # x, y, Breite, Höhe
            values = self.current_content.split(',')
            area = []
            for xy in values:
                area.append(int(int(xy) * self.scale))
            area[0] += self.offset[0]
            area[1] += self.offset[1]
            self.area.append(tuple(area))

        elif name == "room_id":
            self.room_id = int(self.current_content)

        elif name == "light_group_id":
            self.light_group_id = int(self.current_content)

        elif name == "dali_id":
            self.dali_id = int(self.current_content)

        elif name == "dimmable":
            self.dimmable = int(self.current_content)

        elif name == "shape":
            self.shape = self.current_content
 
        elif name == "group":
            self.group = int(self.current_content)

        elif name == "length":
            self.length = int(self.current_content)      
            
        elif name == "room":
            # Der Urspung des Raumes wird in der ersten Fläche erwartet
            self.room_origin.append((self.area[0][0], self.area[0][1]))        
            self.roomlist.append((tuple(self.area), self.name, self.light_group_id))

        elif name == "light":
            # print("Licht :" , self.name, self.room_id, self.typ)
            x = self.room_origin[self.room_id][0]
            y = self.room_origin[self.room_id][1]
            self.lightlist.append((
                self.xy[0] + x, self.xy[1] + y, self.room_id, self.dimmable, self.name, self.shape,
                self.length, self.group, self.dali_id))

        elif name == "switch":
            x = self.room_origin[self.room_id][0]
            y = self.room_origin[self.room_id][1]
            self.switchlist.append(
                (self.xy[0] + x, self.xy[1] + y, self.room_id, self.group))

        elif name == "scale":
            a = self.current_content.split('/')
            self.scale = int(a[0]) / int(a[1])        
            
        elif name == "floorplanfile":
            self.__class__.floorplanfile = self.current_content.strip()

        elif name == "floorplansize":
            size = self.current_content.split(',')
            self.__class__.floorplansize = (int(size[0]), int(size[1]))

        elif name == "floorwindowsize":
            size = self.current_content.split(',')
            self.__class__.floorwindowsize = (int(size[0]), int(size[1]))

        elif name == "projektname":
            self.__class__.projektname = self.current_content

        elif name == "offset":
            size = self.current_content.split(',')
            self.offset = (int(size[0]), int(size[1]))

        elif name == "projekt":
            pass

        else:
            print("unbekanntes Tag: {}".format(name))

        self.current_content = ""


if __name__ == "__main__":
    item = xml_read("Beispiel_sml.xml")
    for i in item:
        print(i)
        print()
