#!/usr/bin/python3
# -*- coding: UTF-8 -*-
#   12.10.2015
#
import tkinter as tk
from tkinter import ttk
from cl_Combo import Combo


# ------------------------------------------------------------------------------
class RoomDialog(object):
    # Ein Dialog für alle Leuchten eines Raumes
    # die können entweder über die lightlist[] des Raumes gefunden werden
    # oder alle Leuchten eines Raumes ggehören einer gemeinsamen Gruppe an
    # dazu muss in diese Gruppe in der room_light_id gekannt gemacht werden.

    # speichert die letzte Szenenauswahl und den Status der Check bzw. Radiobuttons
    last_scene_selection = 0
    last_scene_state = 0

    def __init__(self, master, label="?", level=0):
        self.abbort = False
        self.master = master

        self.top = tk.Toplevel()
        self.top.title("{}".format(label))
        self.top.protocol('WM_DELETE_WINDOW', self._quit)
        self.top.bind('<Escape>', self._quit)
        self.top.resizable(width=False, height=False)  # Größe nicht veränderbar

        xy = (self.master.geometry().split('+'))
        x = int(xy[1]) + 200
        y = int(xy[2]) + 150
        xy = "+{}+{}".format(x, y)
        self.top.geometry(xy)

        self.frm = ttk.LabelFrame(self.top, text="Einstellung aller Raumleuchten")
        self.frm.grid(column=0, row=0, padx=5, pady=5, sticky="NSEW")

        self.scale_var = tk.IntVar()
        self.scale_var.set(int(int(level) * 100 / 254))

        tk.Scale(
            self.frm,  # das Parent-Window
            label="Helligkeit",  # Beschriftung
            showvalue=1,  # [0/1] den Wert anzeigen
            relief="sunken",
            sliderrelief="raised",
            state="normal",  #
            tickinterval=10,  # Interval der Anzeige
            from_=0,  # Wertebereich von ..
            to=100,  # Wertebereich .. bis
            resolution=1,  # Intervall der Werte
            variable=self.scale_var,  # die steuernde Variabel
            width=10,  # die HÃöhe des Scale
            length=300,  # die Länge des Scale
            command=None,
            orient="horizontal"  # die Ausrichtung des Scale
        ).grid(column=0, columnspan=3, row=0, padx=5, pady=5, sticky="new")

        buttons = (("Licht AUS [   0 % ]", 0, 1, self.set_off),
                   ("Licht EIN [ 100 % ]", 2, 1, self.set_on),
                   ("Übernehmen", 2, 2, self.übernehmen),
                   ("Abbrechen", 2, 3, self._quit))

        for b in buttons:
            ttk.Button(self.frm, text=b[0], width=18, command=b[3]).grid(
                column=b[1], row=b[2], padx=5, pady=5, sticky="nsew")

        self.chkscene = tk.IntVar()
        self.chkscene.set(self.__class__.last_scene_state)
        ttk.Checkbutton(self.frm, text="Szene übernehmen", variable=self.chkscene, width=18).grid(
            column=0, row=2, padx=5, pady=5, sticky="nsw")

        self.combo = Combo(self.frm, column=0, row=3)
        self.combo.set_idx(self.__class__.last_scene_selection)

    def start(self):
        self.top.focus_set()  # den Focus auf das Fenster setzen
        self.top.transient(self.master)  # das Fenster im Vordergrund vor "root" halten
        self.top.grab_set()  # events gehen nur an diesen Dialog
        self.top.wait_window(self.top)  # warten bis das Fenster geschlossen wird

        if self.abbort:
            return -1, -1
        elif self.chkscene.get() == 0:
            return int(int(self.scale_var.get()) * 254 / 100), -1
        else:
            return -1, self.combo.get_idx()

    def set_off(self):
        self.chkscene.set(0)
        self.combo.set_idx(0)
        self.scale_var.set(0)

    def set_on(self):
        self.chkscene.set(0)
        self.combo.set_idx(0)
        self.scale_var.set(100)

    def übernehmen(self):
        self.__class__.last_scene_selection = self.combo.get_idx()
        self.__class__.last_scene_state = self.chkscene.get()
        self.top.destroy()

    def _quit(self):
        self.abbort = True
        self.top.destroy()


if __name__ == '__main__':
   top = tk.Tk()
   s = RoomDialog(top)
   print("Ausgewählt wurde:", s.start())
