#!/usr/bin/python
# -*- coding: UTF-8 -*-
#   21.03.2016


class Room(object):
    dali = None

    def __init__(self, master, area, idx, light_group_id, name):
        self.master = master
        self.name = name
        self.idx = idx
        self.light_group_id = light_group_id
        self.area = area
        self.lightlist = []
        self.switchlist = []

    def add_lamp(self, lamp):
        self.lightlist.append(lamp)

    def add_switch(self, switch):
        self.switchlist.append(switch)

    def is_clicked(self, x, y):
        """
        :param x: Mausclick.x
        :param y: Mausclick.y
        prüft, ob der Mausclick innerhalb der Fläche(n) des Raumes stattfand
        :return: idx in der Raumliste / oder (-1)
        """
        for a in self.area:
            if len(a) == 0:
                break
            # prüfen, ob außerhalb einer Fläche
            if x < a[0] or x > a[2] or y < a[1] or y > a[3]:
                continue
            else:
                return self.idx
        return -1

    def get_name(self):
        return self.name

    def set_lamps(self, level):
        """
        Setzt alle Leuchten innerhalb des Raumes auf den Level 'level'
        :param level: Neuer LightLevel für alle Lampen des Raumes
        :return:
        """
        # Alle Leuchten können ggf. über eine Raumgruppe erreicht werden
        # dazu muss eine Gruppen_id < 16 vereinbart sein.
        if self.light_group_id < 16:
            # print("rooms, set lamps", self.light_group_id)
            self.__class__.dali.set_light_by_grp(self.light_group_id, level)
        # wenn keine Gruppe definiert ist, dann muss über die Liste der Leuchten interiert werden
        else:
            for lamp in self.lightlist:
                # print(lamp.dali_id)
                self.__class__.dali.set_light_by_adr(lamp.dali_id, level)

        # Die Anzeige auf dem Bildschirm akualisieren
        for lamp in self.lightlist:
            lamp.set_level(level)

    def set_scenes(self, scene):
        """ Speichert die Helligkeitswerte für alle Leuchten des Raumes als Szene in der Leuchte ab
        :param scene: Index der Scene
        :return:
        """
        for lamp in self.lightlist:
            # Helligkeit nach DTR
            self.__class__.dali.set_light_2_dtr(lamp.dali_id)
            # DTR nach Szene
            self.__class__.dali.set_dtr_2_scene(lamp.dali_id, scene)

    def recall_scenes(self, scene):
        """
        Setzt alle Leuchten des Raumes auf den Wert, der in der jeweiligen Scene der Leuchte
        gespeichert ist.
        :param scene:
        :return:
        """
        if self.light_group_id < 16:
            # print("rooms, set lamps", self.light_group_id)
            self.__class__.dali.recall_scene_by_grp(self.light_group_id, scene)

        # wenn keine Gruppe definiert ist, dann muss über die Liste der Leuchten interiert werden
        else:
            for lamp in self.lightlist:
                self.__class__.dali.recall_scene_by_adr(lamp.dali_id, scene)

        # Anzeige auf dem Bildschirm aktualisieren, dazu den Scenenwert auslesen
        for lamp in self.lightlist:
            light = int(self.__class__.dali.get_scene(lamp.dali_id, scene))
            # ein Fehler liefert -1, und -1 schaltet das Leuchtsymbol auf rot
            # eine Szenenwert von 255 bedeutet, dass die Szene nicht definiert ist
            if light is not 255:
                lamp.set_level(light)

    def delete_scenes(self, scene):
        """ Löscht für alle Leuchten des Raumes die Einstellung für Szene 'scene'
        durch Überschreiben mit dem Wert 255
        :param scene: Index der Scene
        :return:
        """
        # 255 nach DTR schreiben
        self.__class__.dali.set_dtr(255)

        for lamp in self.lightlist:
            self.__class__.dali.set_scene(lamp.dali_id, scene)

    def set_group_level(self, group, level):
        """ Ändert den LightLevel für alle Leuchten der Gruppe 'group'
        :param group: Index der Gruppe
        :param level: Helligkeit, die zugewiesen werden soll
        :return:
        """
        # print(group, type(group), level, type(level))
        self.dali.set_light_by_grp(group, level)
        # auf dem Bildschirm aktualisieren
        for lamp in self.lightlist:
            if lamp.group == group:
                lamp.set_level(level)

    def set_group_scenes(self, group, scene):
        """ Speichert für alle Leuchten einer Gruppe die jeweils aktuellen Lichtwerte in einer Szeneneinstellung
        Dazu uss durch die Liste der Leuchten interiert werden, die jeweils akutelle Helligkeit ausgelesen und
        in der Szene abgelegt werden.
        :param group: Index der Gruppe
        :param scene: Szene, in der die aktuelle Helligkeit gespeichert werden soll
        :return:
        """
        # print("set group scene", group, scene)
        for lamp in self.lightlist:
            if lamp.group == group:
                # Scenenwert auslesen
                # Helligkeit nach DTR
                self.__class__.dali.set_light_2_dtr(lamp.dali_id)
                # DTR nach in die Szene
                self.__class__.dali.set_dtr_2_scene(lamp.dali_id, scene)

    def recall_group_scenes(self, group, scene):
        """
        Aktiviert für alle Leuchten der Gruppe "group" den Szenenwert aus der Szene "scene"
        :param group:
        :param scene:
        :return:
        """
        # print("get_group:", group, "Scene:", scene)
        self.__class__.dali.recall_scene_by_grp(group, scene)

        # Anzeige auf dem Bildschirm
        for lamp in self.lightlist:
            if lamp.group == group:
                light = int(self.__class__.dali.get_scene(lamp.dali_id, scene))
                # ein Fehler liefert -1, und -1 schaltet das Leuchtsymbol auf rot
                # eine Szenenwert von 255 bedeutet, dass die Szene nicht definiert ist
                if light is not 255:
                    lamp.set_level(light)

    def delete_group_scenes(self, group, scene):
        """ Löscht für alle Leuchten einer Gruppe die Szeneneinstellung, der Wert wird auf '255' gesetzt
            zuerst 255 nach DTR schreiben, dann DTR in die Scenen der Leuchten schreiben
            :param group: Die Gruppe, deren Szene gelöscht werden soll
            :param scene: Die Szene, die gelöscht werden soll
        """
        # 255 ins Register DTR schreiben
        self.__class__.dali.set_dtr(255)

        for lamp in self.lightlist:
            if lamp.group == group:
                # den Wert aus dem Register DTR = 255 in die Scene schreiben
                self.__class__.dali.set_dtr_2_scene(lamp.dali_id, scene)
