#!/usr/bin/python3
# -*- coding: UTF-8 -*-
#   12.10.2015
#

import tkinter as tk
from tkinter import ttk
from cl_Combo import Combo


# ------------------------------------------------------------------------------
# noinspection PyPep8Naming,PyPep8Naming,PyPep8Naming
class Scene_Dialog(object):
    """ Ein Dialog zur Zurodnung/Einstellung von Scenen """
    # speichert die letzte Szenenauswahl und Status des Radiobutton
    last_scene_selection = 0
    last_radio_state = 1

    def __init__(self, master, room="", name="", group=""):
        self.abbort = 0
        self.master = master
        self.group = group

        self.top = tk.Toplevel()
        self.top.title("{}, {}, Gruppe {}".format(room, name, group))
        self.top.protocol('WM_DELETE_WINDOW', self._quit)
        self.top.bind('<Escape>', self._quit)
        self.top.resizable(width=False, height=False)  # Größe nicht veränderbar

        xy = (self.master.geometry().split('+'))
        x = int(xy[1]) + 250
        y = int(xy[2]) + 200
        xy = "+{}+{}".format(x, y)
        self.top.geometry(xy)

        self.frm = ttk.LabelFrame(self.top, text="Aktuellen Lightlevel als Scene speichern")
        self.frm.grid(column=0, row=0, padx=5, pady=5, sticky="nsew")

        self.radvar = tk.IntVar()
        self.radvar.set(self.__class__.last_radio_state)
        # Bezeichnung, spalte, zeile, value
        buttons = (("Nur gewählte Leuchte", 0, 0, 1),
                   ("gesamte Gruppe {}".format(group), 0, 1, 2),
                   ("alle Leuchten im Raum", 0, 2, 4))

        for r in buttons:
            ttk.Radiobutton(self.frm, text=r[0], value=r[3], variable=self.radvar).grid(
                column=r[1], row=r[2], padx=5, pady=5, sticky="nsew")

        self.combo = Combo(self.frm, column=1, width=18)
        self.combo.set_idx(self.__class__.last_scene_selection)

        buttons = (("Szene löschen", 2, 0, self.delete_scene),
                   ("Als Szene Übernehmen", 2, 1, self.set_scene),
                   ("Abbrechen", 2, 2, self._quit))

        for b in buttons:
            ttk.Button(self.frm, text=b[0], width=20, command=b[3]).grid(
                column=b[1], row=b[2], padx=5, pady=5, sticky="nsew")

    def start(self):
        self.top.focus_set()  # den Focus auf das Fenster setzen
        self.top.transient(self.master)  # das Fenster im Vordergrund vor "root" halten
        self.top.grab_set()  # events gehen nur an diesen Dialog
        self.top.wait_window(self.top)  # warten bis das Fenster geschlossen wird

        if self.abbort > 0:
            return -1, -1, -1

        else:
            if self.radvar.get() == 1:
                self.group = -1
            elif self.radvar.get() == 4:
                self.group = -2
            return self.combo.get_idx(), self.group, self.abbort

    def set_scene(self):
        self.__class__.last_scene_selection = self.combo.get_idx()
        self.__class__.last_radio_state = self.radvar.get()
        self.abbort = 0
        self.top.destroy()

    def delete_scene(self):
        self.__class__.last_scene_selection = self.combo.get_idx()
        self.__class__.last_radio_state = self.radvar.get()
        self.abbort = -1
        self.top.destroy()

    def _quit(self):
        # Bei einem Abbruch wird None zurückgegeben.
        self.abbort = 1
        self.top.destroy()


if __name__ == '__main__':
    top = tk.Tk()
    s = Scene_Dialog(top, "55", "Testraum")
    print("Ausgewählt wurde:", s.start())
